@@ -743,7 +743,7 @@ show_help_dialog (GtkWindow  *parent,
 	char   *uri;
 	GError *error = NULL;
 
-	uri = g_strconcat ("ghelp:goobox", section ? "?" : NULL, section, NULL);
+	uri = g_strconcat ("ghelp:goobox", ((section != NULL) ? "?" : "?index"), section, NULL);
 	if (! gtk_show_uri (gtk_window_get_screen (parent), uri, GDK_CURRENT_TIME, &error)) {
   		GtkWidget *dialog;
 
